---
title: Home
page_id: home
---

The Crazyflie PC client enables flashing and controlling the Crazyflie. It implements the user interface and high-level control (for example gamepad handling). The communication with Crazyflie and the implementation of the CRTP protocol to control the Crazflie is handled by the [cflib project](https://github.com/bitcraze/crazyflie-lib-python).


![CF client front page](/docs/images/cfclient_frontpage.png)
